function bayer = myfcn_bayerMatrixGeneratorFast(img)
% BAYER = myfcn_bayerMatrixGeneratorFast(IMG)
% converts a 24-bpp RGB color image to a standard Bayer pattern
% color sensor data matrix
% 
% A Bayer matrix senses color in interleaved form following a pattern
% R G R G R ...
% G B G B G .
% R G R G R  .
% G B G B G   .
% R G R G R ...
%
% Thus a Bayer matrix is a 2D matrix which returns only the value
% corresponding to the compnent of color at the sampled location 
% instead of all the 3 color component values per pixel in the input image
%
% (c) 2022, Debdoot Sheet
% ver 1.0 12 August 2022
%
    sz=size(img); % Measure the size of the image
    [cols,rows]=(meshgrid(1:sz(2),1:sz(1))); % Create a mesh grid of X and Y coordinate indices for every pixel location
    channel=uint8(3-(rem(cols,2)+rem(rows,2))); % Identifies the channel to be placed at a specific spatial location. When X & Y are both odd, then sample R, since 3-(rem(X,2)+rem(Y,2))=1; when X & Y are both even, then sample B, since 3-(rem(X,2)+rem(Y,2))=3; when X is even and Y is odd or vice versa, then sample G, since 3-(rem(X,2)+rem(Y,2))=2.
    bayer=reshape(img(sub2ind(sz,rows(:),cols(:),channel(:))),[sz(1),sz(2)]); % Samples the color value following the pattern
end