function bayer = myfcn_bayerMatrixGeneratorVanilla(img)
% BAYER = myfcn_bayerMatrixGeneratorVanilla(IMG)
% converts a 24-bpp RGB color image to a standard Bayer pattern
% color sensor data matrix.
% The function uses the vanilla implementation without acceleration
% 
% A Bayer matrix senses color in interleaved form following a pattern
% R G R G R ...
% G B G B G .
% R G R G R  .
% G B G B G   .
% R G R G R ...
%
% Thus a Bayer matrix is a 2D matrix which returns only the value
% corresponding to the compnent of color at the sampled location 
% instead of all the 3 color component values per pixel in the input image
%
% (c) 2022, Debdoot Sheet
% ver 1.0 12 August 2022
%
    sz=size(img); % Measure the size of the image
    bayer=uint8(zeros(sz(1),sz(2)));
    for rows = 1:sz(1)
        for cols = 1:sz(2)
            if (rem(rows,2)==1)&&(rem(cols,2)==1)
                bayer(rows,cols)=img(rows,cols,1);
            elseif (rem(rows,2)==0)&&(rem(cols,2)==0)
                bayer(rows,cols)=img(rows,cols,3);
            else
                bayer(rows,cols)=img(rows,cols,2);
            end
        end
    end
end