function image = myfcn_deBayerImageGeneratorFast(bayer)
% IMAGE = myfcn_deBayerImageGeneratorFast(BAYER)
% converts a Bayer sensed color matrx to a standard 24-bpp RGB
% color image with 8-bits per color per pixel
% 
% A Bayer matrix senses color in interleaved form following a pattern
% R G R G R ...
% G B G B G .
% R G R G R  .
% G B G B G   .
% R G R G R ...
%
% The De-Bayering produces a 24-bpp standard RGB color image by
% interpolating the missing color component from the neighborhood
% information.
%
% (c) 2022, Debdoot Sheet
% ver 1.0 12 August 2022
%
    sz=size(bayer); % Measure the size of the image
    [cols,rows]=(meshgrid(1:sz(2),1:sz(1))); % Create a mesh grid of X and Y coordinate indices for every pixel location
    channel=uint8(3-(rem(cols,2)+rem(rows,2))); % Identifies the color channel at a specific spatial location. When X & Y are both odd, then sample R, since 3-(rem(X,2)+rem(Y,2))=1; when X & Y are both even, then sample B, since 3-(rem(X,2)+rem(Y,2))=3; when X is even and Y is odd or vice versa, then sample G, since 3-(rem(X,2)+rem(Y,2))=2.
    validloc=cat(3,cat(3,uint8(channel==1),uint8(channel==2)),uint8(channel==3)); % Generates a sparse 3D matrix where 1 in location where a color pixel is samples in Bayer patterm
    imgsparse=repmat(bayer,[1 1 3]).*validloc; % Generates a sparse 3D matrix where the value of the sampled color pixel is located in the corresponding plane
    rh=[1,1,1;1,1,1;1,1,1]; % Define the interpolation neighborhood as a filer kernel for the red channel
    gh=[0,1,0;1,1,1;0,1,0]; % Define the interpolation neighborhood as a filer kernel for the green channel
    bh=rh; % Define the interpolation neighborhood as a filer kernel for the blue channel
    image = uint8(cat(3,cat(3,filter2(rh,imgsparse(:,:,1))./filter2(rh,validloc(:,:,1)),... % Interpolate the red channel to create complete matrix
        filter2(gh,imgsparse(:,:,2))./filter2(gh,validloc(:,:,2))),... % Interpolate the green channel to create complete matrix
        filter2(bh,imgsparse(:,:,3))./filter2(bh,validloc(:,:,3)))); % Interpolate the blue channel to create complete matrix
end