function image = myfcn_deBayerImageGeneratorVanilla(bayer1)
% IMAGE = myfcn_deBayerImageGeneratorVanilla(BAYER)
% converts a Bayer sensed color matrx to a standard 24-bpp RGB
% color image with 8-bits per color per pixel.
% The function uses the vanilla implementation without acceleration
% 
% A Bayer matrix senses color in interleaved form following a pattern
% R G R G R ...
% G B G B G .
% R G R G R  .
% G B G B G   .
% R G R G R ...
%
% The De-Bayering produces a 24-bpp standard RGB color image by
% interpolating the missing color component from the neighborhood
% information.
%
% (c) 2022, Debdoot Sheet
% ver 1.0 12 August 2022
%
    sz=size(bayer1); % Measure the size of the image
    bayer=zeros([sz(1)+2,sz(2)+2]); % Padding of zeros on the boundary for exception handling
    bayer(2:sz(1)+1,2:sz(2)+1)=bayer1;
    image=uint8(zeros([sz(1),sz(2),3]));
    for rows=2:sz(1)+1
        for cols=2:sz(2)+1
            if (rem(rows-1,2)==1)&&(rem(cols-1,2)==1)
                image(rows-1,cols-1,1)=bayer(rows,cols);
                image(rows-1,cols-1,2)=(bayer(rows-1,cols)+bayer(rows+1,cols)+bayer(rows,cols-1)+bayer(rows,cols+1))/4;
                image(rows-1,cols-1,3)=(bayer(rows-1,cols-1)+bayer(rows-1,cols+1)+bayer(rows+1,cols-1)+bayer(rows+1,cols+1))/4;
            elseif (rem(rows-1,2)==0)&&(rem(cols-1,2)==0)
                image(rows-1,cols-1,1)=(bayer(rows-1,cols-1)+bayer(rows-1,cols+1)+bayer(rows+1,cols-1)+bayer(rows+1,cols+1))/4;
                image(rows-1,cols-1,2)=(bayer(rows-1,cols)+bayer(rows+1,cols)+bayer(rows,cols-1)+bayer(rows,cols+1))/4;
                image(rows-1,cols-1,3)=bayer(rows,cols);
            elseif (rem(rows-1,2)==0)&&(rem(cols-1,2)==1)
                image(rows-1,cols-1,1)=(bayer(rows-1,cols)+bayer(rows+1,cols))/2;
                image(rows-1,cols-1,2)=bayer(rows,cols);
                image(rows-1,cols-1,3)=(bayer(rows,cols-1)+bayer(rows,cols+1))/2;
            else
                image(rows-1,cols-1,1)=(bayer(rows,cols-1)+bayer(rows,cols+1))/2;
                image(rows-1,cols-1,2)=bayer(rows,cols);
                image(rows-1,cols-1,3)=(bayer(rows-1,cols)+bayer(rows+1,cols))/2;
            end
        end
    end
end